import { Entry } from "./entry.js";
import { PublicKeyEncryptionResolver } from "@dao-xyz/peerbit-crypto";
import { Encoding } from "./encoding.js";
import { Blocks } from "@dao-xyz/peerbit-block";
export interface EntryFetchOptions<T> {
    length?: number;
    timeout?: number;
    exclude?: any[];
    onProgressCallback?: (entry: Entry<T>) => void;
    concurrency?: number;
    encoding?: Encoding<T>;
    encryption?: PublicKeyEncryptionResolver;
}
interface EntryFetchStrictOptions<T> {
    length: number;
    timeout?: number;
    exclude: any[];
    onProgressCallback?: (entry: Entry<T>) => void;
    concurrency: number;
    encoding?: Encoding<T>;
    encryption?: PublicKeyEncryptionResolver;
}
export interface EntryFetchAllOptions<T> extends EntryFetchOptions<T> {
    shouldExclude?: (string: string) => boolean;
    onStartProgressCallback?: any;
    delay?: number;
}
interface EntryFetchAllStrictOptions<T> extends EntryFetchStrictOptions<T> {
    shouldExclude?: (string: string) => boolean;
    onStartProgressCallback?: any;
    delay: number;
}
export declare const strictAllFetchOptions: <T>(options: EntryFetchAllOptions<T>) => EntryFetchAllStrictOptions<T>;
export declare const strictFetchOptions: <T>(options: EntryFetchOptions<T>) => EntryFetchStrictOptions<T>;
export declare class EntryIO {
    static fetchParallel<T>(store: Blocks, hashes: string | string[], options: EntryFetchAllOptions<T>): Promise<Entry<T>[]>;
    /**
     * Fetch log entries
     *
     * @param {IPFS} [ipfs] An IPFS instance
     * @param {string} [hash] Multihash of the entry to fetch
     * @param {string} [parent] Parent of the node to be fetched
     * @param {Object} [all] Entries to skip
     * @param {Number} [amount=-1] How many entries to fetch
     * @param {Number} [depth=0] Current depth of the recursion
     * @param {function(entry)} shouldExclude A function that can be passed to determine whether a specific hash should be excluded, ie. not fetched. The function should return true to indicate exclusion, otherwise return false.
     * @param {function(entry)} onProgressCallback Called when an entry was fetched
     * @returns {Promise<Array<Entry<T>>>}
     */
    static fetchAll<T>(store: Blocks, hashes: string | string[], fetchOptions: EntryFetchAllOptions<T>): Promise<Entry<T>[]>;
}
export {};
