import { Entry } from "./entry.js";
import { EntryFetchAllOptions } from "./entry-io.js";
import { ISortFunction } from "./log-sorting.js";
import { Blocks } from "@dao-xyz/peerbit-block";
import { Log } from "./log.js";
export declare class LogIO {
    /**
     * Get the multihash of a Log.
     * @param {IPFS} ipfs An IPFS instance
     * @param {Log} log Log to get a multihash for
     * @returns {Promise<string>}
     * @deprecated
     */
    static toMultihash(store: Blocks, log: Log<any>, options?: {
        format?: string;
    }): Promise<string>;
    /**
     * Create a log from a hashes.
     * @param {IPFS} ipfs An IPFS instance
     * @param {string} hash The hash of the log
     * @param {Object} options
     * @param {number} options.length How many items to include in the log
     * @param {Array<Entry<T>>} options.exclude Entries to not fetch (cached)
     * @param {function(hash, entry,  parent, depth)} options.onProgressCallback
     */
    static fromMultihash<T>(store: Blocks, hash: string, options: EntryFetchAllOptions<T> & {
        sortFn: any;
    }): Promise<{
        logId: string;
        entries: any[];
        heads: any[];
    }>;
    /**
     * Create a log from an entry hash.
     * @param {IPFS} ipfs An IPFS instance
     * @param {string} hash The hash of the entry
     * @param {Object} options
     * @param {number} options.length How many items to include in the log
     * @param {Array<Entry<T>>} options.exclude Entries to not fetch (cached)
     * @param {function(hash, entry,  parent, depth)} options.onProgressCallback
     */
    static fromEntryHash<T>(store: Blocks, hash: string[] | string, options: EntryFetchAllOptions<T> & {
        sortFn?: ISortFunction;
    }): Promise<{
        entries: any[];
    }>;
    /**
     * Creates a log data from a JSON object, to be passed to a Log constructor
     *
     * @param {IPFS} ipfs An IPFS instance
     * @param {json} json A json object containing valid log data
     * @param {Object} options
     * @param {number} options.length How many entries to include
     * @param {function(hash, entry,  parent, depth)} options.onProgressCallback
     **/
    static fromJSON<T>(store: Blocks, json: {
        id: string;
        heads: string[];
    }, options: EntryFetchAllOptions<T>): Promise<{
        logId: string;
        entries: Entry<T>[];
        heads: string[];
    }>;
    /**
     * Create a new log starting from an entry.
     * @param {IPFS} ipfs An IPFS instance
     * @param {Entry|Array<Entry<T>>} sourceEntries An entry or an array of entries to fetch a log from
     * @param {Object} options
     * @param {number} options.length How many entries to include
     * @param {Array<Entry<T>>} options.exclude Entries to not fetch (cached)
     * @param {function(hash, entry,  parent, depth)} options.onProgressCallback
     */
    static fromEntry<T>(store: Blocks, sourceEntries: Entry<T>[] | Entry<T>, options: EntryFetchAllOptions<T>): Promise<{
        entries: Entry<T>[];
    }>;
}
